betty.json package - Betty 0.4.0a1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.json package

## Submodules

- betty.json.linked_data module
  - `LinkedDataDumpable`
    - `LinkedDataDumpable.dump_linked_data()`
    - `LinkedDataDumpable.linked_data_schema()`
  - `add_json_ld()`
  - `dump_context()`
  - `dump_link()`
  - `ref_json_ld()`
- betty.json.schema module
  - `Schema`
    - `Schema.__init__()`
    - `Schema.build()`
    - `Schema.validate()`
  - `add_property()`
  - `ref_json_schema()`
  - `ref_locale()`

## Module contents

Provide JSON utilities.